==> httrack_3.33.16.orig.tar.gz: httrack-3.33.16/src/htsjava.h <==
/* ------------------------------------------------------------ */
/*
HTTrack Website Copier, Offline Browser for Windows and Unix
Copyright (C) Xavier Roche and other contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


Important notes:

- We hereby ask people using this source NOT to use it in purpose of grabbing
emails addresses, or collecting any other private information on persons.
This would disgrace our work, and spoil the many hours we spent on it.


Please visit our Website: http://www.httrack.com
*/


/* ------------------------------------------------------------ */
/* File: Java classes parser .h                                 */
/* Author: Yann Philippot                                       */
/* ------------------------------------------------------------ */


#ifndef HTSJAVA_DEFH
#define HTSJAVA_DEFH 

#include <stdio.h>
#include "htsmodules.h"

typedef struct  {
  unsigned long  int magic;
  unsigned short int minor;
  unsigned short int major;
  unsigned short int count;
} JAVA_HEADER;

typedef struct {
  int file_position;
  //
  unsigned int index1;
  unsigned int type;
  char name[1024];
} RESP_STRUCT;


/* Library internal definictions */
#ifdef HTS_INTERNAL_BYTECODE
int hts_detect_java(htsmoduleStruct* str);
int hts_parse_java(htsmoduleStruct* str);
RESP_STRUCT affecte(int i1,int i2,RESP_STRUCT *i3,RESP_STRUCT *i4,int i5);
//unsigned int swap(long int nomber,int digit);
RESP_STRUCT readtable(htsmoduleStruct* str,FILE *fp,RESP_STRUCT,int*);
unsigned short int readshort(FILE *fp);
int tris(char*);
char * printname(char [1024]);
#endif

#endif

==> httrack_3.43.2.orig.tar.gz: httrack-3.43.2/src/htsjava.h <==
/* ------------------------------------------------------------ */
/*
HTTrack Website Copier, Offline Browser for Windows and Unix
Copyright (C) Xavier Roche and other contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


Important notes:

- We hereby ask people using this source NOT to use it in purpose of grabbing
emails addresses, or collecting any other private information on persons.
This would disgrace our work, and spoil the many hours we spent on it.


Please visit our Website: http://www.httrack.com
*/


/* ------------------------------------------------------------ */
/* File: Java classes parser .h                                 */
/* Author: Yann Philippot                                       */
/* ------------------------------------------------------------ */


#ifndef HTSJAVA_DEFH
#define HTSJAVA_DEFH 

#ifndef HTS_DEF_FWSTRUCT_JAVA_HEADER
#define HTS_DEF_FWSTRUCT_JAVA_HEADER
typedef struct JAVA_HEADER JAVA_HEADER;
#endif
struct JAVA_HEADER {
  unsigned long  int magic;
  unsigned short int minor;
  unsigned short int major;
  unsigned short int count;
};

#ifndef HTS_DEF_FWSTRUCT_RESP_STRUCT
#define HTS_DEF_FWSTRUCT_RESP_STRUCT
typedef struct RESP_STRUCT RESP_STRUCT;
#endif
struct RESP_STRUCT {
  int file_position;
  //
  unsigned int index1;
  unsigned int type;
  char name[1024];
};


/* Library internal definictions */
#ifdef HTS_INTERNAL_BYTECODE

EXTERNAL_FUNCTION int hts_plug_java(httrackp *opt, const char* argv);

#endif

#endif
